/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Leon Rigoni
 *
 */

#include "ShootableObstacle.h"
#include "core/XMLPort.h"

namespace orxonox
{
    RegisterClass(ShootableObstacle);

    ShootableObstacle::ShootableObstacle(Context* context) : Pawn(context)
    {
        RegisterObject(ShootableObstacle);
        this->enableCollisionCallback();
    }

    bool ShootableObstacle::collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint)
    {
        if (GameMode::isMaster() && enableCollisionDamage_)
        {
            Pawn* victim = orxonox_cast<Pawn*>(otherObject);
            if (victim)
            {
                float damage = this->collisionDamage_ * (victim->getVelocity() - this->getVelocity()).length();
                victim->hit(nullptr, contactPoint, ownCollisionShape, damage);
            }
        }

        return false;
    }

    void ShootableObstacle::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(ShootableObstacle, XMLPort, xmlelement, mode);

        XMLPortParam(ShootableObstacle, "enablecollisiondamage", setEnableCollisionDamage, getEnableCollisionDamage, xmlelement, mode).defaultValues(false);
        XMLPortParam(ShootableObstacle, "collisiondamage", setCollisionDamage, getCollisionDamage, xmlelement, mode).defaultValues(1);
    }

}