/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Nikola Bolt
 *   Co-Author:
 *      Claudio Fanconi
 *
 */

/**
    @file StoryModePawn.cc
    @brief Implementation of the StoryModePawn control
*/

#include "StoryModePawn.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"

#include "graphics/Camera.h"

#include <BulletCollision/NarrowPhaseCollision/btManifoldPoint.h>

namespace orxonox
{
    RegisterClass(StoryModePawn);

    StoryModePawn::StoryModePawn(Context* context) : SpaceShip(context)
    {
        RegisterObject(StoryModePawn);
    }

    void StoryModePawn::moveFrontBack(const Vector2& value)
        {
            //this->getCamera()->setOrientation(Vector3::UNIT_X, Degree(-30));
            Vector3 newPos = this->getCamera()->getPosition();
            newPos.z -= 5*value.x;
            this->getCamera()->setPosition(newPos);
        }

    void StoryModePawn::moveRightLeft(const Vector2& value)
        {   
            Vector3 newPos = this->getCamera()->getPosition();
            newPos.x += 5*value.x;
            this->getCamera()->setPosition(newPos);
        }

    void StoryModePawn::moveUpDown(const Vector2& value) {}

    void StoryModePawn::rotateYaw(const Vector2& value) {

        Pawn::rotateYaw(value);
    }

    /**
    @brief
        Removed, does nothing.
    @param value
    */
    void StoryModePawn::rotatePitch(const Vector2& value) { }

    /**
    @brief
        Removed, does nothing.
    @param value
    */
    void StoryModePawn::rotateRoll(const Vector2& value) { }

    /**
    @brief
        Removed, does nothing
    @param bBoost
    */
    void StoryModePawn::boost(bool bBoost) { }
}
